@@ -17,12 +17,13 @@ from .status import (
     WEBSOCKET_CLOSED,
     Status,
 )
+from os import getenv
 
 logger = getLogger(__name__)
 raw_logger = getLogger(f'{__name__}.raw')
 
-USER_URL = "wss://stream.crypto.com/exchange/v1/user"
-MARKET_URL = "wss://stream.crypto.com/exchange/v1/market"
+USER_URL = getenv("CRYPTODOTCOM_USER_URL", "wss://stream.crypto.com/exchange/v1/user")
+MARKET_URL = getenv("CRYPTODOTCOM_MARKET_URL", "wss://stream.crypto.com/exchange/v1/market")
 
 
 def raw_websocket_connection(
