@@ -4,7 +4,7 @@ import enum
 class MethodName(str, enum.Enum):
     AUTHENTICATE = "public/auth"
     CANCEL_ALL = "private/cancel-all-orders"
-    CANCEL_ORDER = "private/cancel-order-list"
+    CANCEL_ORDER = "private/cancel-order"
     CLOSE_POSITION = "private/close-position"
     CREATE_ORDER = "private/create-order"
     GET_DEPOSIT_ADDRESS = "private/get-deposit-address"
